@@ -4,15 +4,12 @@ from typing import List
 
 import click
 
+from ggshield.utils import EMPTY_SHA, SupportedCI, SupportedScanMode
+
 from .dev_scan import scan_commit_range
 from .git_shell import check_git_dir, get_list_commit_SHA
 
 
-SUPPORTED_CI = "[GITLAB | TRAVIS | CIRCLE | GITHUB ACTIONS | BITBUCKET PIPELINES]"
-
-NO_BEFORE = "0000000000000000000000000000000000000000"
-
-
 def jenkins_range(verbose: bool) -> List[str]:  # pragma: no cover
     head_commit = os.getenv("GIT_COMMIT")
     previous_commit = os.getenv("GIT_PREVIOUS_COMMIT")
@@ -119,7 +116,7 @@ def gitlab_ci_range(verbose: bool) -> List[str]:  # pragma: no cover
     commit_sha = os.getenv("CI_COMMIT_SHA", "HEAD")
     if verbose:
         click.echo(f"CI_COMMIT_BEFORE_SHA: {before_sha}\nCI_COMMIT_SHA: {commit_sha}")
-    if before_sha and before_sha != NO_BEFORE:
+    if before_sha and before_sha != EMPTY_SHA:
         commit_list = get_list_commit_SHA("{}~1...".format(before_sha))
         if commit_list:
             return commit_list
@@ -152,12 +149,12 @@ def github_actions_range(verbose: bool) -> List[str]:  # pragma: no cover
             f"github_head_sha: {head_sha}"
         )
 
-    if push_before_sha and push_before_sha != NO_BEFORE:
+    if push_before_sha and push_before_sha != EMPTY_SHA:
         commit_list = get_list_commit_SHA("{}...".format(push_before_sha))
         if commit_list:
             return commit_list
 
-    if pull_req_base_sha and pull_req_base_sha != NO_BEFORE:
+    if pull_req_base_sha and pull_req_base_sha != EMPTY_SHA:
         commit_list = get_list_commit_SHA("{}..".format(pull_req_base_sha))
         if commit_list:
             return commit_list
@@ -202,27 +199,34 @@ def ci_cmd(ctx: click.Context) -> int:  # pragma: no cover
 
         if os.getenv("GITLAB_CI"):
             commit_list = gitlab_ci_range(config.verbose)
+            ci_env = SupportedCI.GITLAB
         elif os.getenv("GITHUB_ACTIONS"):
             commit_list = github_actions_range(config.verbose)
+            ci_env = SupportedCI.GITHUB
         elif os.getenv("TRAVIS"):
             commit_list = travis_range(config.verbose)
-        elif os.getenv("JENKINS_HOME"):
+            ci_env = SupportedCI.TRAVIS
+        elif os.getenv("JENKINS_HOME") or os.getenv("JENKINS_URL"):
             commit_list = jenkins_range(config.verbose)
+            ci_env = SupportedCI.JENKINS
         elif os.getenv("CIRCLECI"):
             commit_list = circle_ci_range(config.verbose)
+            ci_env = SupportedCI.CIRCLECI
         elif os.getenv("BITBUCKET_COMMIT"):
             commit_list = bitbucket_pipelines_range(config.verbose)
+            ci_env = SupportedCI.BITBUCKET
 
         else:
             raise click.ClickException(
-                "Current CI is not detected or supported. Must be one of {}".format(
-                    SUPPORTED_CI
-                )
+                f"Current CI is not detected or supported."
+                f"Must be one of [{' | '.join([ci.value for ci in SupportedCI])}]"
             )
 
         if config.verbose:
             click.echo(f"Commits to scan: {len(commit_list)}")
 
+        mode_header = "/".join([SupportedScanMode.CI.value, ci_env.value])
+
         return scan_commit_range(
             client=ctx.obj["client"],
             cache=ctx.obj["cache"],
@@ -233,6 +237,7 @@ def ci_cmd(ctx: click.Context) -> int:  # pragma: no cover
             matches_ignore=config.matches_ignore,
             all_policies=config.all_policies,
             scan_id=" ".join(commit_list),
+            mode_header=mode_header,
         )
     except click.exceptions.Abort:
         return 0
