@@ -1,13 +1,15 @@
 import copy
 import json
 import os
-from typing import Any, Dict, List, NamedTuple
+from typing import Any, Dict, List, NamedTuple, Set
 
 import click
 import yaml
 from dotenv import load_dotenv
 from pygitguardian.models import PolicyBreak
 
+from ggshield.filter import get_ignore_sha
+
 from .git_shell import get_git_root, is_git_dir
 from .text_utils import display_error
 
@@ -17,6 +19,9 @@ CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 # max file size to accept
 MAX_FILE_SIZE = 1048576
 
+# Max commits to scan on a prepush
+MAX_PREPUSH_COMMITS = 100
+
 CPU_COUNT = os.cpu_count() or 1
 
 
@@ -37,8 +42,8 @@ class Config:
     all_policies: bool
     api_url: str
     exit_zero: bool
-    matches_ignore: set
-    paths_ignore: set
+    matches_ignore: List
+    paths_ignore: Set
     show_secrets: bool
     verbose: bool
 
@@ -54,7 +59,7 @@ class Config:
         Attribute("all_policies", False),
         Attribute("api_url", "https://api.gitguardian.com"),
         Attribute("exit_zero", False),
-        Attribute("matches_ignore", set()),
+        Attribute("matches_ignore", list()),
         Attribute("paths_ignore", set()),
         Attribute("show_secrets", False),
         Attribute("verbose", False),
@@ -78,8 +83,8 @@ class Config:
     def update_config(self, **kwargs: Any) -> None:
         for key, item in kwargs.items():
             if key in self.get_attributes_keys():
-                if isinstance(item, list):
-                    getattr(self, key).update(item)
+                if isinstance(getattr(self, key), list):
+                    getattr(self, key).extend(item)
                 else:
                     setattr(self, key, item)
             else:
@@ -133,8 +138,8 @@ class Config:
 
         with open(config_file, "w") as f:
             try:
-                stream = yaml.dump(self.to_dict(), default_flow_style=False)
-                f.write(stream.replace("- ", "  - "))
+                stream = yaml.dump(self.to_dict(), indent=2, default_flow_style=False)
+                f.write(stream)
 
             except Exception as e:
                 raise click.ClickException(
@@ -142,10 +147,23 @@ class Config:
                 )
         return True
 
-    def add_ignored_match(self, secret_hash: str) -> None:
+    def add_ignored_match(self, secret: dict) -> None:
         """ Add secret to matches_ignore. """
-        current_ignored = self.matches_ignore
-        current_ignored.add(secret_hash)
+
+        matches_ignore = [
+            match["match"] if isinstance(match, dict) else match
+            for match in self.matches_ignore
+        ]
+        if secret["match"] not in matches_ignore:
+            self.matches_ignore.append(secret)
+        else:
+            for match in self.matches_ignore:
+                if (
+                    isinstance(match, dict)
+                    and match["match"] == secret["match"]
+                    and match["name"] == ""
+                ):
+                    match.update({"name": secret["name"]})
 
 
 def load_dot_env() -> None:
@@ -170,12 +188,11 @@ def load_dot_env() -> None:
 
 
 class Cache:
-
-    last_found_secrets: set
+    last_found_secrets: List
 
     CACHE_FILENAME = "./.cache_ggshield"
     attributes: List[Attribute] = [
-        Attribute("last_found_secrets", set()),
+        Attribute("last_found_secrets", list()),
     ]
 
     def __init__(self) -> None:
@@ -191,9 +208,26 @@ class Cache:
             list(zip(*self.attributes))[0]
         )  # get list of first elements in tuple
 
+    def __setattr__(self, name: str, value: Any) -> None:
+        if isinstance(value, list):
+            attribute = getattr(self, name)
+
+            if isinstance(attribute, list):
+                for elem in value:
+                    if elem not in attribute:
+                        attribute.append(elem)
+            else:
+                getattr(self, name).update(value)
+        else:
+            super().__setattr__(name, value)
+
     def create_empty_cache(self) -> None:
         # Creates a new file
-        with open(self.CACHE_FILENAME, "w"):
+        try:
+            with open(self.CACHE_FILENAME, "w"):
+                pass
+        except PermissionError:
+            # Hotfix: for the time being we skip cache handling if permission denied
             pass
 
     def load_cache(self) -> bool:
@@ -203,17 +237,24 @@ class Cache:
 
         _cache: dict = {}
         if os.stat(self.CACHE_FILENAME).st_size != 0:
-            with open(self.CACHE_FILENAME, "r") as f:
-                try:
-                    _cache = json.load(f)
-                    # Convert back all sets that were serialized as lists
-                    for attr in self.attributes:
-                        if type(attr.default) is set and attr.name in _cache:
-                            _cache[attr.name] = set(_cache[attr.name]) or set()
-                except Exception as e:
-                    raise click.ClickException(
-                        f"Parsing error while reading {self.CACHE_FILENAME}:\n{str(e)}"
-                    )
+            try:
+                f = open(self.CACHE_FILENAME, "r")
+            except PermissionError:
+                # Hotfix: for the time being we skip cache handling if permission denied
+                return True
+            else:
+                with f:
+                    try:
+                        _cache = json.load(f)
+                        # Convert back all sets that were serialized as lists
+                        for attr in self.attributes:
+                            if type(attr.default) is set and attr.name in _cache:
+                                _cache[attr.name] = set(_cache[attr.name]) or set()
+                    except Exception as e:
+                        raise click.ClickException(
+                            "Parsing error while"
+                            f"reading {self.CACHE_FILENAME}:\n{str(e)}"
+                        )
         self.update_cache(**_cache)
         return True
 
@@ -221,9 +262,14 @@ class Cache:
         for key, item in kwargs.items():
             if key in self.get_attributes_keys():
                 if isinstance(item, list):
-                    getattr(self, key).update(item)
+                    attr = getattr(self, key)
+                    for elem in item:
+                        if elem not in attr:
+                            attr.append(elem)
                 else:
                     setattr(self, key, item)
+
+                setattr(self, key, item)
             else:
                 click.echo("Unrecognized key in cache: {}".format(key))
 
@@ -240,26 +286,38 @@ class Cache:
         if not os.path.isfile(self.CACHE_FILENAME):
             return False
 
-        with open(self.CACHE_FILENAME, "w") as f:
-            try:
-                json.dump(self.to_dict(), f)
+        try:
+            f = open(self.CACHE_FILENAME, "w")
+        except PermissionError:
+            # Hotfix: for the time being we skip cache handling if permission denied
+            return True
+        else:
+            with f:
+                try:
+                    json.dump(self.to_dict(), f)
 
-            except Exception as e:
-                raise click.ClickException(
-                    f"Error while saving cache in {self.CACHE_FILENAME}:\n{str(e)}"
-                )
+                except Exception as e:
+                    raise click.ClickException(
+                        f"Error while saving cache in {self.CACHE_FILENAME}:\n{str(e)}"
+                    )
         return True
 
     def purge(self) -> None:
         for attr in self.attributes:
             # Deep copy to avoid mutating the default value
             default = copy.copy(attr.default)
-            setattr(self, attr.name, default)
+            super().__setattr__(attr.name, default)
 
-    def add_found_secret(self, hash: str) -> None:
-        self.last_found_secrets.add(hash)
-
-    def add_found_policy_break(self, policy_break: PolicyBreak) -> None:
-        if policy_break.policy.lower() == "secrets detection":
-            for match in policy_break.matches:
-                self.add_found_secret(match.match)
+    def add_found_policy_break(self, policy_break: PolicyBreak, filename: str) -> None:
+        if policy_break.is_secret:
+            ignore_sha = get_ignore_sha(policy_break)
+            if not any(
+                last_found["match"] == ignore_sha
+                for last_found in self.last_found_secrets
+            ):
+                self.last_found_secrets.append(
+                    {
+                        "name": f"{policy_break.break_type} - {filename}",
+                        "match": get_ignore_sha(policy_break),
+                    }
+                )
