@@ -9,15 +9,15 @@ from typing import Iterable, Iterator, List, Set
 import click
 from pygitguardian import GGClient
 
-from ggshield.output import OutputHandler, TextHandler
+from ggshield.output import OutputHandler
 from ggshield.scan import Commit, ScanCollection
 from ggshield.text_utils import STYLE, format_text
 
 from .config import CPU_COUNT, Cache, Config
 from .filter import path_filter_set
-from .git_shell import GIT_PATH, check_git_dir, get_list_commit_SHA, is_git_dir, shell
+from .git_shell import GIT_PATH, get_list_commit_SHA, is_git_dir, shell
 from .path import get_files_from_paths
-from .utils import REGEX_GIT_URL
+from .utils import REGEX_GIT_URL, SupportedScanMode
 
 
 @contextmanager
@@ -53,6 +53,7 @@ def scan_repo_path(
                 matches_ignore=config.matches_ignore,
                 all_policies=config.all_policies,
                 scan_id=scan_id,
+                mode_header=SupportedScanMode.REPO.value,
             )
     except click.exceptions.Abort:
         return 0
@@ -101,6 +102,11 @@ def repo_cmd(ctx: click.Context, repository: str) -> int:  # pragma: no cover
                 scan_id=repository,
             )
 
+    if any(host in repository for host in ("gitlab.com", "github.com")):
+        raise click.ClickException(
+            f"{repository} doesn't seem to be a valid git URL.\n"
+            f"Did you mean {repository}.git?"
+        )
     raise click.ClickException(f"{repository} is neither a valid path nor a git URL")
 
 
@@ -132,6 +138,7 @@ def range_cmd(ctx: click.Context, commit_range: str) -> int:  # pragma: no cover
             matches_ignore=config.matches_ignore,
             all_policies=config.all_policies,
             scan_id=commit_range,
+            mode_header=SupportedScanMode.COMMIT_RANGE.value,
         )
     except click.exceptions.Abort:
         return 0
@@ -141,40 +148,6 @@ def range_cmd(ctx: click.Context, commit_range: str) -> int:  # pragma: no cover
         raise click.ClickException(str(error))
 
 
-@click.command()
-@click.argument("precommit_args", nargs=-1, type=click.UNPROCESSED)
-@click.pass_context
-def precommit_cmd(
-    ctx: click.Context, precommit_args: List[str]
-) -> int:  # pragma: no cover
-    """
-    scan as a pre-commit git hook.
-    """
-    config = ctx.obj["config"]
-    output_handler = TextHandler(
-        show_secrets=config.show_secrets, verbose=config.verbose, output=None
-    )
-    try:
-        check_git_dir()
-        results = Commit(filter_set=ctx.obj["filter_set"]).scan(
-            client=ctx.obj["client"],
-            cache=ctx.obj["cache"],
-            matches_ignore=config.matches_ignore,
-            all_policies=config.all_policies,
-            verbose=config.verbose,
-        )
-
-        return output_handler.process_scan(
-            ScanCollection(id="cached", type="pre-commit", results=results)
-        )[1]
-    except click.exceptions.Abort:
-        return 0
-    except Exception as error:
-        if config.verbose:
-            traceback.print_exc()
-        raise click.ClickException(str(error))
-
-
 @click.command()
 @click.argument(
     "paths", nargs=-1, type=click.Path(exists=True, resolve_path=True), required=True
@@ -204,6 +177,7 @@ def path_cmd(
             matches_ignore=config.matches_ignore,
             all_policies=config.all_policies,
             verbose=config.verbose,
+            mode_header=SupportedScanMode.PATH.value,
         )
         scan = ScanCollection(id=" ".join(paths), type="path_scan", results=results)
 
@@ -223,6 +197,7 @@ def scan_commit(
     verbose: bool,
     matches_ignore: Iterable[str],
     all_policies: bool,
+    mode_header: str,
 ) -> ScanCollection:  # pragma: no cover
     results = commit.scan(
         client=client,
@@ -230,6 +205,7 @@ def scan_commit(
         matches_ignore=matches_ignore,
         all_policies=all_policies,
         verbose=verbose,
+        mode_header=mode_header,
     )
 
     return ScanCollection(
@@ -251,16 +227,19 @@ def scan_commit_range(
     matches_ignore: Iterable[str],
     all_policies: bool,
     scan_id: str,
+    mode_header: str,
 ) -> int:  # pragma: no cover
     """
     Scan every commit in a range.
 
     :param client: Public Scanning API client
-    :param commit_range: Range of commits to scan (A...B)
+    :param commit_list: List of commits sha to scan
     :param verbose: Display successfull scan's message
     """
     return_code = 0
-    with concurrent.futures.ThreadPoolExecutor(max_workers=CPU_COUNT) as executor:
+    with concurrent.futures.ThreadPoolExecutor(
+        max_workers=min(CPU_COUNT, 4)
+    ) as executor:
         future_to_process = [
             executor.submit(
                 scan_commit,
@@ -270,6 +249,7 @@ def scan_commit_range(
                 verbose,
                 matches_ignore,
                 all_policies,
+                mode_header,
             )
             for sha in commit_list
         ]
