@@ -20,6 +20,9 @@ REGEX_HEADER_INFO = re.compile(
     r"Author:\s(?P<author>.+?)\ <(?P<email>.+?)>\nDate:\s+(?P<date>.+)?\n"
 )
 
+EMPTY_SHA = "0000000000000000000000000000000000000000"
+EMPTY_TREE = "4b825dc642cb6eb9a060e54bf8d69288fbee4904"
+
 
 class Filemode(Enum):
     """
@@ -163,3 +166,21 @@ def update_policy_break_matches(
         match.index_end = match.index_end - index - int(is_patch) + 1
         match.line_start = start_line
         match.line_end = line_index
+
+
+class SupportedCI(Enum):
+    GITLAB = "GITLAB"
+    TRAVIS = "TRAVIS"
+    CIRCLECI = "CIRCLECI"
+    JENKINS = "JENKINS HOME"
+    GITHUB = "GITHUB ACTIONS"
+    BITBUCKET = "BITBUCKET PIPELINES"
+
+
+class SupportedScanMode(Enum):
+    REPO = "repo"
+    PATH = "path"
+    COMMIT_RANGE = "commit_range"
+    PRE_COMMIT = "pre_commit"
+    PRE_PUSH = "pre_push"
+    CI = "ci"
